==> openGion7.2.4.0_dev.zip: uap/webapps/ge/db/HSQLDB/sql/install/01_TABLE/GEA06S.sql <==
/****************************************************************************/
/* GEA06 ( ﾃﾞｰﾀﾛｰﾙﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2018/09/28 16:03:23                                            */
/****************************************************************************/

CREATE TABLE GEA06 (
   SYSTEM_ID    VARCHAR  (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID   */
 , DROLE        VARCHAR  (  20 )                    NOT NULL            /*  20 ﾃﾞｰﾀﾛｰﾙ  */
 , CLM          VARCHAR  (  30 )                    NOT NULL            /*  30 項目     */
 , CVALUE       VARCHAR  ( 200 )                    NOT NULL            /*  40 値       */
 , VALCDTN      VARCHAR  (  10 )                    NOT NULL            /*  50 条件     */
 , UNIQ         IDENTITY                                                /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR  (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR  (  14 )                                        /* 820 登録日時 */
 , PGSET        VARCHAR  (  10 )                                        /* 830 作成PG   */
 , PGPSET       VARCHAR  (  10 )                                        /* 840 作成親PG */
 , USRSET       VARCHAR  (  10 )                                        /* 850 作成者   */
 , DYUPD        VARCHAR  (  14 )                                        /* 860 更新日時 */
 , PGUPD        VARCHAR  (  10 )                                        /* 870 更新PG   */
 , PGPUPD       VARCHAR  (  10 )                                        /* 880 更新親PG */
 , USRUPD       VARCHAR  (  10 )                                        /* 890 更新者   */
);

==> openGion7.3.1.3_dev.zip: uap/webapps/ge/db/HSQLDB/sql/install/01_TABLE/GEA06S.sql <==
/****************************************************************************/
/* GEA06 ( ﾃﾞｰﾀﾛｰﾙﾏｽﾀ )                                                     */
/*                                                                          */
/* Created : 2020/12/16 08:13:57                                            */
/****************************************************************************/

CREATE TABLE GEA06 (
   SYSTEM_ID    VARCHAR  (  10 )                    NOT NULL            /*  10 ｼｽﾃﾑID   */
 , DROLE        VARCHAR  (  20 )                    NOT NULL            /*  20 ﾃﾞｰﾀﾛｰﾙ  */
 , CLM          VARCHAR  (  30 )                    NOT NULL            /*  30 項目     */
 , CVALUE       VARCHAR  ( 200 )                    NOT NULL            /*  40 値       */
 , VALCDTN      VARCHAR  (  10 )                    NOT NULL            /*  50 条件     */
 , UNIQ         IDENTITY                                                /* 800 ﾕﾆｰｸｷｰ   */
 , FGJ          VARCHAR  (   1 )        DEFAULT '1' NOT NULL            /* 810 状態ﾌﾗｸﾞ */
 , DYSET        VARCHAR  (  14 )                                        /* 820 作成日時 */
 , PGSET        VARCHAR  (  10 )                                        /* 830 作成PG   */
 , PGPSET       VARCHAR  (  10 )                                        /* 840 作成親PG */
 , USRSET       VARCHAR  (  10 )                                        /* 850 作成者   */
 , DYUPD        VARCHAR  (  14 )                                        /* 860 更新日時 */
 , PGUPD        VARCHAR  (  10 )                                        /* 870 更新PG   */
 , PGPUPD       VARCHAR  (  10 )                                        /* 880 更新親PG */
 , USRUPD       VARCHAR  (  10 )                                        /* 890 更新者   */
);
